@@ -5,7 +5,7 @@ log_f_post_Omega <- function(Omega,
   ###     Metropolis-Hastings for correlations of sigma_Z given by 'Omega'     ###
   # target distribution: log-posterior distribution of 'sigma_jk' #
 
-  if(all(dim(Z)==!dim(mu_Z))) {
+  if(any(dim(Z)!=dim(mu_Z))) {
     cat('\nError: Problem simulating sigma: Dimension of Z and mu_Z are not equal \n')
     stop('Problem simulating sigma: Dimension of Z and mu_Z are not equal')
   }
@@ -19,8 +19,10 @@ log_f_post_Omega <- function(Omega,
     S_mat <- S_mat + 1/sampling_prob[i] * aux_s %*% t(aux_s)
   }
   #browser()
-  log_posterior_Omega <- -(1/2)*(n_q+1) * sum(log(abs(diag(Omega)))) - (1/2) * (n+2-n_q*(n_q-1)) * det(Omega) - (1/2) * sum(diag( solve(Omega) %*% (solve(Lambda) %*% S_mat %*% solve(Lambda)) ))
-
+  log_posterior_Omega <- 0
+  log_posterior_Omega <- log_posterior_Omega - (1/2) * (n_q+1) * sum(log(abs(diag(Omega))))
+  log_posterior_Omega <- log_posterior_Omega - (1/2) * (n+2-n_q*(n_q-1)) * det(Omega)
+  log_posterior_Omega <- log_posterior_Omega - (1/2) * sum(diag( solve(Omega) %*% (solve(Lambda) %*% S_mat %*% solve(Lambda)) ))
   return( log_posterior_Omega )
 }
 
